from setuptools import setup

setup(name='annobase',
      packages=['annobase'],
      version='0.0.1',
      descriptions='a text annotation tool that aims to provide a light-weight but comprehensive represenation for text annotation',
      url='http://junaraki.net/software/annobase',
      author='Jun Araki',
      author_email='mail@junaraki.net',
)
